[![Stars](https://img.shields.io/github/stars/scverse/scanpy?logo=GitHub&color=yellow)](https://github.com/HanwenXuTHU/BioTranslatorProject)
[![PyPI](https://img.shields.io/pypi/v/scanpy?logo=PyPI)](https://pypi.org/project/biotranslator/)
[![PyPIDownload](https://static.pepy.tech/badge/biotranslator)](https://pepy.tech/project/biotranslator)
[![Doc](https://readthedocs.org/projects/biotranslator/badge/?version=latest)](https://biotranslator.readthedocs.io/en/latest/?badge=latest)


# BioTranslator API

BioTranslator is a cross-modal translator which can annotate biology instances only using user-written texts.
The codes here can reproduce the main results in BioTranslator paper, including zero-shot protein function prediction, zero-shot cell type prediction, and predict the nodes and edges of a gene pathway.
BioTranslator takes a user-written textual description of the new discovery and then translates this description to a non-text biological data instance. Our tool frees scientists from limiting their analysis within predefined controlled vocabularies, thus accelerating new biomedical discoveries.

[documentation]: https://biotranslator.readthedocs.io

For more information, please visit the project's main repository [here](https://github.com/HanwenXuTHU/BioTranslatorProject).